.. _api:

API Documentation
=================

.. autosummary::
    :toctree: _autosummary

    dnadna
    dnadna.simulation
    dnadna.data_preprocessing
    dnadna.training
    dnadna.nets
    dnadna.transforms
    dnadna.summary_statistics
    dnadna.simulator
    dnadna.snp_sample
    dnadna.datasets
    dnadna.params
    dnadna.utils
    dnadna.examples
